aboutsummaryrefslogtreecommitdiffstats
path: root/sys/syz-sysgen
diff options
context:
space:
mode:
authorTobias Klauser <tklauser@distanz.ch>2020-06-25 19:17:17 +0200
committerDmitry Vyukov <dvyukov@google.com>2020-06-26 16:41:30 +0200
commita7c0649868090238541a8f62854cb7fe64dc6fc4 (patch)
treed2eaa6a44a9311109292ff9b6999a10f912d54da /sys/syz-sysgen
parent42306a435d930eba6b8f1c447a2a7ca50410f533 (diff)
sys/syz-sysgen: ignore *_kvm.txt on linux/riscv64
The Linux RISC-V port in linux-next doesn't support KVM yet. Ignore it for now until KVM support is added upstream. Signed-off-by: Tobias Klauser <tklauser@distanz.ch>
Diffstat (limited to 'sys/syz-sysgen')
-rw-r--r--sys/syz-sysgen/sysgen.go8
1 files changed, 5 insertions, 3 deletions
diff --git a/sys/syz-sysgen/sysgen.go b/sys/syz-sysgen/sysgen.go
index b0d7fbbab..5fc2be7b7 100644
--- a/sys/syz-sysgen/sysgen.go
+++ b/sys/syz-sysgen/sysgen.go
@@ -114,9 +114,11 @@ func main() {
return
}
top := descriptions
- if OS == "linux" && job.Target.Arch == "arm" {
- // Hack: KVM is not supported on ARM anymore.
- // Note: syz-extract also ignores this file for arm.
+ if OS == "linux" && (job.Target.Arch == "arm" || job.Target.Arch == "riscv64") {
+ // Hack: KVM is not supported on ARM anymore. On riscv64 it
+ // is not supported yet but might be in the future.
+ // Note: syz-extract also ignores this file for arm and
+ // riscv64.
top = descriptions.Filter(func(n ast.Node) bool {
pos, _, _ := n.Info()
return !strings.HasSuffix(pos.File, "_kvm.txt")